@@ -81,7 +81,9 @@ class CAMB(GetTransfer):
         
         .. note :: This should not be called by the user!
         """
-        self.t.transfer_options.update(self.option_defaults)
+        for k in self.option_defaults:
+            if k not in self.t.transfer_options:
+                self.t.transfer_options[k] = self.option_defaults[k]
 
         cdict = dict(self.t.pycamb_dict,
                      **self.t.transfer_options)
@@ -220,6 +222,9 @@ class Transfer(Cosmology):
         (CAMB-only) Number of threads to use for calculation of transfer 
         function by CAMB. Default 0 automatically determines the number.
                        
+    takahashi : bool, default ``True``
+        Whether to use updated HALOFIT coefficients from Takahashi+12
+        
     kwargs : keywords
         The ``**kwargs`` take any cosmological parameters desired, which are 
         input to the `hmf.cosmo.Cosmology` class. `hmf.Perturbations` uses a 
@@ -252,7 +257,7 @@ class Transfer(Cosmology):
     def __init__(self, z=0.0, lnk_min=np.log(1e-8),
                  lnk_max=np.log(2e4), dlnk=0.05,
                  wdm_mass=None, transfer_fit=CAMB,
-                 transfer_options={}, **kwargs):
+                 transfer_options={}, takahashi=True, **kwargs):
         '''
         Initialises some parameters
         '''
@@ -267,6 +272,7 @@ class Transfer(Cosmology):
         self.z = z
         self.transfer_fit = transfer_fit
         self.transfer_options = transfer_options
+        self.takahashi = takahashi
 
     def update(self, **kwargs):
         """
@@ -315,6 +321,10 @@ class Transfer(Cosmology):
     def dlnk(self, val):
         return val
 
+    @parameter
+    def takahashi(self, val):
+        return val
+
     @parameter
     def z(self, val):
         try:
@@ -354,7 +364,7 @@ class Transfer(Cosmology):
     def lnk(self):
         return np.arange(self.lnk_min, self.lnk_max, self.dlnk)
 
-    @cached_property("lnk", "pycamb_dict", "camb_options")
+    @cached_property("lnk", "pycamb_dict", "transfer_options", "transfer_fit")
     def _unnormalised_lnT(self):
         """
         The un-normalised transfer function
@@ -389,7 +399,7 @@ class Transfer(Cosmology):
         """
         return tools.normalize(self.sigma_8,
                                self._unnormalised_lnT,
-                               self.lnk, self.mean_dens)
+                               self.lnk, self.mean_dens)[0]
 
     @cached_property("wdm_mass", "_lnP_cdm_0", "lnk", "h", "omegac")
     def _lnP_0(self):
@@ -397,12 +407,12 @@ class Transfer(Cosmology):
         Normalised log power at :math:`z=0` (for CDM/WDM)
         """
         if self.wdm_mass is not None:
-            print "doing this coz wdm_mass is ", self.wdm_mass
             return tools.wdm_transfer(self.wdm_mass, self._lnP_cdm_0,
                                       self.lnk, self.h, self.omegac)
         else:
             return self._lnP_cdm_0
 
+
     @cached_property("z", "omegam", "omegav", "omegak")
     def growth(self):
         r"""
@@ -439,8 +449,11 @@ class Transfer(Cosmology):
         """
         Normalised log transfer function for CDM/WDM
         """
-        return tools.wdm_transfer(self.wdm_mass, self._lnT_cdm,
-                                  self.lnk, self.h, self.omegac)
+        if self.wdm_mass is not None:
+            return tools.wdm_transfer(self.wdm_mass, self._lnT_cdm,
+                                      self.lnk, self.h, self.omegac)
+        else:
+            return self._lnT_cdm
 
     @cached_property("lnk", "power")
     def delta_k(self):
@@ -464,7 +477,7 @@ class Transfer(Cosmology):
         """
         return -3 * self.lnk + self.nonlinear_delta_k + np.log(2 * np.pi ** 2)
 
-    @cached_property("delta_k", "lnk", "z", "omegam", "omegav", "omegak", "omegan", 'w')
+    @cached_property("delta_k", "lnk", "z", "omegam", "omegav", "omegak", "omegan", 'w', 'takahashi')
     def nonlinear_delta_k(self):
         r"""
         Dimensionless nonlinear power spectrum, :math:`\Delta_k = \frac{k^3 P_{\rm nl}(k)}{2\pi^2}`
@@ -474,7 +487,7 @@ class Transfer(Cosmology):
         plin = np.exp(self.delta_k[mask])
         k = np.exp(self.lnk[mask])
         pnl = halofit(k, self.z, self.omegam, self.omegav, self.w, self.omegan,
-                      rneff, rncur, rknl, plin)
+                      rneff, rncur, rknl, plin, self.takahashi)
         nonlinear_delta_k = np.exp(self.delta_k)
         nonlinear_delta_k[mask] = pnl
         nonlinear_delta_k = np.log(nonlinear_delta_k)
